@@ -86,7 +86,7 @@ BTNRST = "Reset"
 LBLPROTDISP = "Protocols Shown"
 LBLDATADISP = "Console Display"
 LBLUBXCONFIG = "UBX\nConfiguration"
-LBLNTRIPCONFIG = "NTRIP\nConfiguration"
+LBLNTRIPCONFIG = "NTRIP Client\nConfiguration"
 LBLNTRIPGGAINT = "GGA Interval"
 LBLCTL = "Controls"
 LBLSET = "Settings"
@@ -106,6 +106,10 @@ LBLNTRIPMOUNT = "Mountpoint"
 LBLNTRIPUSER = "User"
 LBLNTRIPPWD = "Password"
 LBLNTRIPSTR = "Sourcetable"
+LBLSOCKSERVE = "Socket / NTRIP\nServer              "  # padded to align
+LBLSERVERPORT = "Port"
+LBLDEGFORMAT = "Degrees Format"
+LBLSERVERMODE = "Mode"
 
 # Dialog text
 DLGUBXCONFIG = "UBX Configuration"
